==> schemaapp-8.x-1.1.tar.gz: schemaapp/tests/src/Unit/CacheTest.php <==
<?php

namespace Drupal\Tests\schemaapp\Unit;

use Drupal\Tests\UnitTestCase;
use function GuzzleHttp\json_decode;

/**
 * Testing for the Cache tool fetching from Schema App CDN.
 *
 * @group schemaapp
 */
class CacheTest extends UnitTestCase {

  /**
   * Test with URL Params.
   */
  public function testUsingParams() {
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com?application=drupal";

    $this->assertNotNull($url);

    $cacheService = new SchemaAppCacheService($url, $config);

    $item = $cacheService->get();

    $this->assertNotEmpty($item);

    $jsonArray = json_decode($item, TRUE);

    $this->assertEquals("Schema App URL Params", $jsonArray['name']);

  }

  /**
   * Test without url parameters.
   */
  public function testNoUrlParams() {
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com/node/1";

    $schemaCache = new SchemaAppCacheService($url, $config);

    $this->assertNotNull($schemaCache);
    $text = $schemaCache->get();
    $this->assertNotEmpty($text);

    $jsonArray = json_decode($text, TRUE);

    $this->assertArrayHasKey('@type', $jsonArray);

    // Ensure content is valid.
    $this->assertEquals("Schema App", $jsonArray['name']);

    // Try the same url with params that need to be stripped.
    $noParamsConfig = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => FALSE,
    ];

    $paramsToRemoveUrl = "http://drupal8.ugoziedge.com/node/1?drupal=true";
    $schemaCacheNoParams = new SchemaAppCacheService($paramsToRemoveUrl, $noParamsConfig);

    $noParamsData = $schemaCacheNoParams->get();
    $this->assertNotNull($noParamsData);
    $jsonArrayNoParams = json_decode($noParamsData, TRUE);
    $this->assertEquals($jsonArray, $jsonArrayNoParams);

  }

  /**
   * Tests url param sorting.
   *
   * Tests that url params are sorted and retrieve the same item
   * no matter the order.
   */
  public function testSortedParams() {
    $config = [
      "account_id" => "DrupalEightTest",
      "api_key" => "HLD5-AS53-LH74-MGO8",
      "use_url_params" => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com?a=2&b=1";
    $unSorted = "http://drupal8.ugoziedge.com?b=1&a=2";

    $schemaCache = new SchemaAppCacheService($url, $config);

    $schemaCacheUnSorted = new SchemaAppCacheService($unSorted, $config);

    $this->assertNotNull($schemaCache);
    $this->assertNotNull($schemaCacheUnSorted);

    $data = $schemaCache->get();
    $dataUnSorted = $schemaCacheUnSorted->get();

    $this->assertNotEmpty($data);
    $this->assertNotEmpty($dataUnSorted);

    $this->assertEquals($data, $dataUnSorted);

    $wrongUrl = "http://drupal8.ugoziedge.com?a=1&b=2";

    $schemaCacheNoUrl = new SchemaAppCacheService($wrongUrl, $config);

    $this->assertNotEquals($schemaCacheNoUrl->get(), $dataUnSorted);

  }

  /**
   * Test the Guzzle Connection Timeout.
   */
  public function testConnectionTimeout() {
    $noParamsConfig = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => FALSE,
      'api_timeout' => 1,
    ];

    $paramsToRemoveUrl = "http://drupal8.ugoziedge.com/node/1?drupal=true";
    $schemaCacheNoParams = new SchemaAppCacheService($paramsToRemoveUrl, $noParamsConfig);

    $noParamsData = $schemaCacheNoParams->get();
    $this->assertNotNull($noParamsData);

  }

}

==> schemaapp-8.x-1.4.tar.gz: schemaapp/tests/src/Unit/CacheTest.php <==
<?php

namespace Drupal\Tests\schemaapp\Unit;

use Drupal\Tests\UnitTestCase;
use function GuzzleHttp\json_decode;

/**
 * Testing for the Cache tool fetching from Schema App CDN.
 *
 * @group schemaapp
 */
class CacheTest extends UnitTestCase {

  /**
   * Test with URL Params.
   */
  public function testUsingParams() {
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com?application=drupal";

    $this->assertNotNull($url);

    $cacheService = new SchemaAppCacheService($url, $config);

    $data = $cacheService->get();

    $this->assertNotEmpty($data);

    $jsonArray = json_decode($data[0], TRUE);

    $this->assertEquals("Schema App URL Params", $jsonArray['name']);

  }

  /**
   * Test without url parameters.
   */
  public function testNoUrlParams() {
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com/node/1";

    $schemaCache = new SchemaAppCacheService($url, $config);

    $this->assertNotNull($schemaCache);
    $data = $schemaCache->get();
    $this->assertNotEmpty($data);

    $jsonArray = json_decode($data[0], TRUE);

    $this->assertArrayHasKey('@type', $jsonArray);

    // Ensure content is valid.
    $this->assertEquals("Schema App", $jsonArray['name']);

    // Try the same url with params that need to be stripped.
    $noParamsConfig = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => FALSE,
    ];

    $paramsToRemoveUrl = "http://drupal8.ugoziedge.com/node/1?drupal=true";
    $schemaCacheNoParams = new SchemaAppCacheService($paramsToRemoveUrl, $noParamsConfig);

    $noParamsData = $schemaCacheNoParams->get();
    $this->assertNotNull($noParamsData);
    $jsonArrayNoParams = json_decode($noParamsData[0], TRUE);
    $this->assertEquals($jsonArray, $jsonArrayNoParams);

  }

  /**
   * Tests url param sorting.
   *
   * Tests that url params are sorted and retrieve the same item
   * no matter the order.
   */
  public function testSortedParams() {
    $config = [
      "account_id" => "DrupalEightTest",
      "api_key" => "HLD5-AS53-LH74-MGO8",
      "use_url_params" => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com?a=2&b=1";
    $unSorted = "http://drupal8.ugoziedge.com?b=1&a=2";

    $schemaCache = new SchemaAppCacheService($url, $config);

    $schemaCacheUnSorted = new SchemaAppCacheService($unSorted, $config);

    $this->assertNotNull($schemaCache);
    $this->assertNotNull($schemaCacheUnSorted);

    $data = $schemaCache->get();
    $dataUnSorted = $schemaCacheUnSorted->get();

    $this->assertNotEmpty($data);
    $this->assertNotEmpty($dataUnSorted);

    $this->assertEquals($data, $dataUnSorted);

    $wrongUrl = "http://drupal8.ugoziedge.com?a=1&b=2";

    $schemaCacheNoUrl = new SchemaAppCacheService($wrongUrl, $config);

    $this->assertNotEquals($schemaCacheNoUrl->get(), $dataUnSorted);

  }

  /**
   * Test the Guzzle Connection Timeout.
   */
  public function testConnectionTimeout() {
    $noParamsConfig = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => FALSE,
      'api_timeout' => 1,
    ];

    $paramsToRemoveUrl = "http://drupal8.ugoziedge.com/node/1?drupal=true";
    $schemaCacheNoParams = new SchemaAppCacheService($paramsToRemoveUrl, $noParamsConfig);

    $noParamsData = $schemaCacheNoParams->get();
    $this->assertNotNull($noParamsData);

  }

  /**
   * Test for multiple sources of markup, includes editor and highlighter.
   */
  public function testWithHighlighterCache() {
    // Same URL used for each cache check
    $url = 'http://drupal8.ugoziedge.com/node/1';

    // First check uses no highlighter markup
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_highlighter_markup' => FALSE,
    ];

    $cache = new SchemaAppCacheService($url, $config);
    $this->assertNotNull($cache);

    $data = $cache->get();
    $this->assertNotEmpty($data);
    $this->assertCount(1, $data);

    $jsonArray = json_decode($data[0], TRUE);
    $this->assertEquals("Schema App", $jsonArray['name']);

    // Second check uses highlighter markup
    $highlighterConfig = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_highlighter_markup' => TRUE,
    ];

    $highlighterCache = new SchemaAppCacheService($url, $highlighterConfig);
    $this->assertNotNull($highlighterCache);

    $highlighterData = $highlighterCache->get();
    $this->assertNotEmpty($highlighterData);
    $this->assertCount(2, $highlighterData);

    $jsonArray = json_decode($highlighterData[0], TRUE);
    $this->assertEquals("Schema App", $jsonArray['name']);

    $highlighterJsonArray = json_decode($highlighterData[1], TRUE);
    $this->assertEquals("Highlighter Markup", $highlighterJsonArray['name']);
  }

}
